## What is New
### Version 0.6
- Added web server to set configuration and product list easily
- Hepsiburada scraper updated
### Version 0.5
- Some bugs are fixed and includes code refactor works
- Random user agent for get requests
- ebay.com, morhipo.com, teknostore.com, letgo.com, kitapyurdu.com, tozlu.com, dr.com.tr, toyzzshop.com, 
decathlon.com.tr, nike.com scrapers are added
- issue templates are published
### Version 0.4
- Some bugs are fixed and includes code refactor works
- More understandable error messages for the user
- Removing commands that has error
- teknosa.com, n11.com, ciceksepeti.net, ciceksepeti.com, mediamarkt.com.tr scraper are added
- code of conduct is published